==> serviziopubblico_0.2.9.tar.gz: serviziopubblico-0.2.9/puntatemain.cpp <==
#include "puntatemain.h"
#include "ui_puntatemain.h"
#include "config.h"

#include <QProcess>
#include <QDesktopServices>
#include <QFileDialog>
#include <QDialog>

PuntateMain::PuntateMain(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::PuntateMain)
{
    ui->setupUi(this);

    setAttribute(Qt::WA_Maemo5StackedWindow);
    setWindowFlags(windowFlags() | Qt::Window);
}

PuntateMain::~PuntateMain()
{
    delete ui;
}

void PuntateMain::on_pushButton_22_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d1.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream1_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p1.sh");
    process.waitForFinished();
}

void PuntateMain::on_down2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d2.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p2.sh");
    process.waitForFinished();
}

void PuntateMain::on_down3_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d3.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream3_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p3.sh");
    process.waitForFinished();
}

void PuntateMain::on_down4_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d4.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream4_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p4.sh");
    process.waitForFinished();
}

void PuntateMain::on_down5_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d5.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream5_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p5.sh");
    process.waitForFinished();
}

void PuntateMain::on_down6_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d6.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream6_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p6.sh");
    process.waitForFinished();
}

void PuntateMain::on_down7_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d7.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream7_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p7.sh");
    process.waitForFinished();
}

void PuntateMain::on_down8_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d8.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream8_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p8.sh");
    process.waitForFinished();
}

void PuntateMain::on_down9_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d9.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream9_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p9.sh");
    process.waitForFinished();
}

void PuntateMain::on_down10_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d10.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream10_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p10.sh");
    process.waitForFinished();
}

void PuntateMain::on_down11_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d11.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream11_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p11.sh");
    process.waitForFinished();
}

void PuntateMain::on_down12_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d12.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream12_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p12.sh");
    process.waitForFinished();
}

void PuntateMain::on_down13_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d13.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream13_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p13.sh");
    process.waitForFinished();
}

void PuntateMain::on_actionPuntate_Scaricate_triggered()
{
    QString fileName = QFileDialog::getOpenFileName(this,
         tr("Locate Download Show"),
         USER_DIR,
         tr("Show (*.mp4)"));
    if (!fileName.isEmpty())
        {
        QProcess process;
        QString program = "/opt/kmplayer/bin/kmplayer";
        QStringList arguments;
        arguments <<  fileName;

        process.start(program, arguments);
        if (!process.waitForFinished())
        return;
        }
}

void PuntateMain::on_down13_2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d14.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream13_2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p14.sh");
    process.waitForFinished();
}

void PuntateMain::on_down15_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d15.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream15_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p15.sh");
    process.waitForFinished();
}

==> serviziopubblico_0.3.1.tar.gz: serviziopubblico-0.3.1/puntatemain.cpp <==
#include "puntatemain.h"
#include "ui_puntatemain.h"
#include "config.h"

#include <QProcess>
#include <QDesktopServices>
#include <QFileDialog>
#include <QDialog>

PuntateMain::PuntateMain(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::PuntateMain)
{
    ui->setupUi(this);

    setAttribute(Qt::WA_Maemo5StackedWindow);
    setWindowFlags(windowFlags() | Qt::Window);
}

PuntateMain::~PuntateMain()
{
    delete ui;
}

void PuntateMain::on_pushButton_22_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d1.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream1_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p1.sh");
    process.waitForFinished();
}

void PuntateMain::on_down2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d2.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p2.sh");
    process.waitForFinished();
}

void PuntateMain::on_down3_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d3.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream3_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p3.sh");
    process.waitForFinished();
}

void PuntateMain::on_down4_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d4.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream4_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p4.sh");
    process.waitForFinished();
}

void PuntateMain::on_down5_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d5.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream5_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p5.sh");
    process.waitForFinished();
}

void PuntateMain::on_down6_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d6.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream6_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p6.sh");
    process.waitForFinished();
}

void PuntateMain::on_down7_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d7.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream7_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p7.sh");
    process.waitForFinished();
}

void PuntateMain::on_down8_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d8.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream8_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p8.sh");
    process.waitForFinished();
}

void PuntateMain::on_down9_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d9.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream9_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p9.sh");
    process.waitForFinished();
}

void PuntateMain::on_down10_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d10.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream10_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p10.sh");
    process.waitForFinished();
}

void PuntateMain::on_down11_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d11.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream11_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p11.sh");
    process.waitForFinished();
}

void PuntateMain::on_down12_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d12.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream12_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p12.sh");
    process.waitForFinished();
}

void PuntateMain::on_down13_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d13.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream13_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p13.sh");
    process.waitForFinished();
}

void PuntateMain::on_actionPuntate_Scaricate_triggered()
{
    QString fileName = QFileDialog::getOpenFileName(this,
         tr("Locate Download Show"),
         USER_DIR,
         tr("Show (*.mp4)"));
    if (!fileName.isEmpty())
        {
        QProcess process;
        QString program = "/opt/kmplayer/bin/kmplayer";
        QStringList arguments;
        arguments <<  fileName;

        process.start(program, arguments);
        if (!process.waitForFinished())
        return;
        }
}

void PuntateMain::on_down13_2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d14.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream13_2_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p14.sh");
    process.waitForFinished();
}

void PuntateMain::on_down15_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d15.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream15_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p15.sh");
    process.waitForFinished();
}

void PuntateMain::on_down16_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/d16.sh");
    process.waitForFinished();
}

void PuntateMain::on_stream16_clicked()
{
    QProcess process;
    process.start("sh /opt/serviziopubblico/script/p16.sh");
    process.waitForFinished();
}
